@@ -1,6 +1,6 @@
 from __future__ import annotations
 import numpy as np
-import pandas as pd
+from numpy.typing import DTypeLike
 import os
 from functools import partial
 import inspect
@@ -8,8 +8,8 @@ from warnings import warn
 from scipy import ndimage as ndi
 
 from .specials import PropArray
-from .utils._skimage import skmes, skseg
-from .utils import _misc, _docs
+from ._utils._skimage import skmes, skseg
+from ._utils import _misc, _docs
 from .bases import HistoryArray
 from .label import Label
 
@@ -17,11 +17,10 @@ from ..utils.misc import check_nd, largest_zeros
 from ..utils.utilcls import Progress
 from ..utils.axesop import complement_axes, find_first_appeared, del_axis, axes_included
 from ..utils.deco import record, dims_to_spatial_axes
-from ..utils.io import imwrite, get_imsave_meta_from_img
+from ..utils.io import save_mrc, save_tif
 
 from ..collections import DataList
 from ..axes import ImageAxesError
-from ..frame import MarkerFrame
 from .._types import Dims, nDInt, nDFloat, Callable, Coords, Iterable
 
 class LabeledArray(HistoryArray):
@@ -62,74 +61,52 @@ class LabeledArray(HistoryArray):
                 "   history    ": "->".join(self.history)}
     
     
-    def imsave(self, tifname: str, dtype=None):
+    def imsave(self, save_path: str, dtype: DTypeLike = None):
         """
-        Save image at the same directory as the original image by default. If the image contains
-        wrong axes for ImageJ (= except for tzcyx), then it will converted automatically if possible.
-        zyx-scale is also saved.
+        Save image at the same directory as the original image by default. For tif file format, if the
+        image contains wrong axes for ImageJ (= except for tzcyx), then it will converted automatically 
+        if possible. For mrc file format, only zyx and yx is allowed. zyx-scale is also saved.
 
         Parameters
         ----------
-        tifname : str
+        save_path : str
             File name.
-        dtype : Any that can be interpreted as numpy.dtype, optional
+        dtype : dtype-like, optional
             In what data type img will be saved.
         
         Returns
         -------
         None
         """        
-        # set default values
-        if not tifname.endswith(".tif"):
-            tifname += ".tif"
-        if os.sep not in tifname:
+        save_path = str(save_path)
+        _, ext = os.path.splitext(save_path)
+        
+        if ext == "":
+            save_path += ".tif"
+            ext = ".tif"
+    
+        if os.sep not in save_path:
             if self.dirpath is None:
                 raise ValueError(
-                    "Image directory path is unknown. Set by "
-                    " >>> img.dirpath = \"...\""
-                    "or specify absolute path like"
+                    "Image directory path is unknown. Set by \n"
+                    " >>> img.dirpath = \"...\"\n"
+                    "or specify absolute path like\n"
                     " >>> img.imsave(\"/path/to/XXX.tif\")"
                     )
-            tifname = os.path.join(self.dirpath, tifname)
+            save_path = os.path.join(self.dirpath, save_path)
         if self.metadata is None:
             self.metadata = {}
         if dtype is None:
             dtype = self.dtype
             
-        # change axes if needed
-        rest_axes = complement_axes(self.axes, "tzcyx")
-        new_axes = ""
-        axes_changed = False
-        for a in self.axes:
-            if a in "tzcyx":
-                new_axes += a
-            else:
-                if len(rest_axes) == 0:
-                    raise ImageAxesError(f"Cannot save image with axes {self.axes}")
-                new_axes += rest_axes[0]
-                rest_axes = rest_axes[1:]
-                axes_changed = True
-        
-        # make a copy of the image for saving
-        if new_axes != self.axes:
-            img = self.copy()
-            img.axes = new_axes
-            img.set_scale(self)
-        else:
-            img = self
-        img = img.as_img_type(dtype).sort_axes()
-        imsave_kwargs = get_imsave_meta_from_img(img, update_lut=True)
-
         # save image
-        imwrite(tifname, img, **imsave_kwargs)
+        if ext == ".tif":
+            save_tif(save_path, self)
+        elif ext == ".mrc":
+            save_mrc(save_path, self)
 
-        # notifications
-        if axes_changed:
-            if new_axes == str(img.axes):
-                print(f"Image axes changed: {self.axes} -> {new_axes}")
-            else:
-                print(f"Image axes changed and sorted: {self.axes} -> {new_axes} -> {img.axes}")
-        print(f"Succesfully saved: {tifname}")
+        # notification
+        print(f"Succesfully saved: {save_path}")
         return None
     
     # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -267,14 +244,14 @@ class LabeledArray(HistoryArray):
         """
         Show intensity profile.
         """
-        from .utils import _plot as _plt
+        from ._utils import _plot as _plt
         _plt.hist(self.value, contrast)
 
         return None
 
     @dims_to_spatial_axes
     def imshow(self, dims=2, **kwargs):
-        from .utils import _plot as _plt
+        from ._utils import _plot as _plt
         if self.ndim == 1:
             _plt.plot_1d(self.value, **kwargs)
         elif self.ndim == 2:
@@ -302,7 +279,7 @@ class LabeledArray(HistoryArray):
         return self
 
     def imshow_comparewith(self, other: LabeledArray, **kwargs):
-        from .utils import _plot as _plt
+        from ._utils import _plot as _plt
         fig, ax = _plt.subplots(1, 2, figsize=(8, 4))
         _plt.plot_2d(self.value, ax=ax[0], **kwargs)
         _plt.plot_2d(other.value, ax=ax[1], **kwargs)        
@@ -311,7 +288,7 @@ class LabeledArray(HistoryArray):
     
     @dims_to_spatial_axes
     def imshow_label(self, alpha=0.3, dims=2, **kwargs):
-        from .utils import _plot as _plt
+        from ._utils import _plot as _plt
         if not hasattr(self, "labels"):
             raise AttributeError("No label to show.")
         if self.ndim == 2:
@@ -539,8 +516,9 @@ class LabeledArray(HistoryArray):
             >>> img.specify(coords, 3.5, filt=filter_func, labeltype="circle")
             >>> ip.gui.add(img)
         """
+        from ..frame import MarkerFrame
         if isinstance(center, MarkerFrame):
-            from .utils._process_numba import _specify_circ_2d, _specify_circ_3d, _specify_square_2d, _specify_square_3d
+            from ._utils._process_numba import _specify_circ_2d, _specify_circ_3d, _specify_square_2d, _specify_square_3d
             ndim = len(dims)
             radius = np.asarray(check_nd(radius, ndim), dtype=np.float32)
             
@@ -632,7 +610,7 @@ class LabeledArray(HistoryArray):
             length = int(np.ceil(np.sqrt(np.sum(d**2)) + 1))
             coords = np.vstack([np.linspace(src_, dst_, length) for src_, dst_ in zip(src, dst)])
         else:    
-            from .utils._process_numba import _get_coordinate
+            from ._utils._process_numba import _get_coordinate
             
             each_length = np.sqrt(np.sum(np.diff(a, axis=0)**2, axis=1))
             total_length = np.sum(each_length)
@@ -770,6 +748,7 @@ class LabeledArray(HistoryArray):
             >>>     return lbl[yc, xc] > 0
             >>> img.label_if(lbl, filt)
         """        
+        import pandas as pd
         # check the shape of label_image
         if label_image is None:
             label_image = self
@@ -934,7 +913,7 @@ class LabeledArray(HistoryArray):
         return imgs
     
     def tile(self, shape: tuple[int, int] = None, along: str = None, order: str = None) -> LabeledArray:
-        """
+        r"""
         Tile images in a certain order. Label is also tiled in the same manner.
 
         Parameters
