@@ -1,11 +1,10 @@
 from __future__ import annotations
-import scipy
 import numpy as np
 from warnings import warn
 from .arrays import ImgArray, PropArray
-from .arrays.utils import _docs
-from .arrays.utils._corr import subpixel_pcc
-from .utils.axesop import *
+from .arrays._utils import _docs
+from .arrays._utils._corr import subpixel_pcc
+from .utils.axesop import complement_axes, add_axes
 from .utils.utilcls import Progress
 from .utils.deco import dims_to_spatial_axes
 from ._cupy import xp, asnumpy, xp_ndi
