@@ -11,8 +11,18 @@ from qtpy.QtGui import QCursor
 
 from .widgets import *
 from .widgets.table import read_csv
-from .utils import *
-from .._const import SetConst
+from .utils import (
+    get_a_selected_layer, 
+    iter_selected_layer, 
+    crop_rectangle,
+    crop_rotated_rectangle,
+    get_viewer_scale, 
+    make_world_scale,
+    to_labels
+    )
+from .._const import Const, SetConst
+from ..arrays import ImgArray, Label, PhaseArray, LabeledArray, LazyImgArray
+
 
 __all__ = ["add_imread_menu",
            "add_imsave_menu",
@@ -63,7 +73,7 @@ def add_imread_menu(viewer:"napari.Viewer"):
         hist = history.get_open_history()
         dlg.setHistory(hist)
         filenames, _ = dlg.getOpenFileNames(
-            parent=viewer.window.qt_viewer,
+            parent=viewer.window._qt_window,
             caption="Select file ...",
             directory=hist[0],
         )
@@ -98,7 +108,7 @@ def add_imsave_menu(viewer:"napari.Viewer"):
         else:
             last_hist = hist[0]
         filename, _ = dlg.getSaveFileName(
-            parent=viewer.window.qt_viewer,
+            parent=viewer.window._qt_window,
             caption="Save image layer",
             directory=last_hist,
         )
@@ -120,7 +130,7 @@ def add_read_csv_menu(viewer:"napari.Viewer"):
         hist = history.get_open_history()
         dlg.setHistory(hist)
         filenames, _ = dlg.getOpenFileNames(
-            parent=viewer.window.qt_viewer,
+            parent=viewer.window._qt_window,
             caption="Select file ...",
             directory=hist[0],
         )
@@ -575,7 +585,7 @@ def layer_template_matcher(viewer:"napari.Viewer"):
                            template={"label": "temp",
                                      "tooltip": "Template image. This image will move."},
                            ndim={"choices": [2, 3]})
-        def template_matcher(img:Image, template:Image, ndim=2):
+        def template_matcher(img: Image, template: Image, ndim=2):
             step = viewer.dims.current_step[:-min(ndim, img.ndim)]
             img_ = img.data[step]
             template_ = template.data[step]
@@ -618,6 +628,7 @@ def function_handler(viewer:"napari.Viewer"):
             napari.types.LayerDataTuple
                 This is passed to napari and is directly visualized.
             """
+            from ..frame import MarkerFrame, TrackFrame, PathFrame
             outlist = []
             for input in viewer.layers.selection:
                 data = layer_to_impy_object(viewer, input)
